@@ -16,7 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function
 import os
 import os.path
 
@@ -24,7 +23,6 @@ from .. import qtall as qt
 from .. import setting
 from .. import utils
 from .. import document
-from ..compat import citems, cstrerror, cstr, cgetcwd
 from .veuszdialog import VeuszDialog
 
 def _(text, disambiguation=None, context='ExportDialog'):
@@ -62,7 +60,7 @@ class ExportDialog(VeuszDialog):
         self.updatePagePages()
 
         # change 'Save' button to 'Export'
-        self.buttonBox.button(qt.QDialogButtonBox.Save).setText(_('Export'))
+        self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Save).setText(_('Export'))
 
         # these are mappings between filetypes and radio buttons
         self.fmtradios = dict([(f, getattr(self, r)) for f, r in formatradio])
@@ -73,14 +71,14 @@ class ExportDialog(VeuszDialog):
         for types, descr in document.AsyncExport.getFormats():
             docfmts.update(types)
         # disable type if not allowed
-        for fmt, radio in citems(self.fmtradios):
+        for fmt, radio in self.fmtradios.items():
             if fmt not in docfmts:
                 radio.setEnabled(False)
 
         # connect format radio buttons
         def fmtclicked(f):
             return lambda: self.formatClicked(f)
-        for r, f in citems(self.radiofmts):
+        for r, f in self.radiofmts.items():
             r.clicked.connect(fmtclicked(f))
 
         # connect page radio buttons
@@ -100,7 +98,7 @@ class ExportDialog(VeuszDialog):
         if eloc == 'doc':
             self.dirname = os.path.dirname(os.path.abspath(docfilename))
         elif eloc == 'cwd':
-            self.dirname = cgetcwd()
+            self.dirname = os.getcwd()
         else: # 'prev'
             self.dirname = setdb.get('dirname_export', qt.QDir.homePath())
 
@@ -139,9 +137,9 @@ class ExportDialog(VeuszDialog):
         self.fmtradios[ext].click()
 
         # regexp for comma separated ranges
-        valre = qt.QRegExp(
+        valre = qt.QRegularExpression(
             r'^[0-9]+(\s*-\s*[0-9]+)?(\s*,\s*[0-9]+(\s*-\s*[0-9]+)?)*$')
-        valid = qt.QRegExpValidator(valre, self)
+        valid = qt.QRegularExpressionValidator(valre, self)
         self.editPagePages.setValidator(valid)
 
         # set page mode
@@ -205,9 +203,9 @@ class ExportDialog(VeuszDialog):
         dirname = os.path.dirname(self.editFileName.text())
         fd.setDirectory(dirname if dirname else self.dirname)
 
-        fd.setFileMode(qt.QFileDialog.AnyFile)
-        fd.setAcceptMode(qt.QFileDialog.AcceptSave)
-        fd.setOptions(qt.QFileDialog.DontConfirmOverwrite)
+        fd.setFileMode(qt.QFileDialog.FileMode.AnyFile)
+        fd.setAcceptMode(qt.QFileDialog.AcceptMode.AcceptSave)
+        fd.setOptions(qt.QFileDialog.Option.DontConfirmOverwrite)
 
         # Create a mapping between a format string and extensions
         filtertoext = {}
@@ -235,7 +233,7 @@ class ExportDialog(VeuszDialog):
         if os.path.isdir(dirname):
             fd.selectFile(filename)
 
-        if fd.exec_() == qt.QDialog.Accepted:
+        if fd.exec() == qt.QDialog.DialogCode.Accepted:
             # convert filter to extension
             filterused = str(fd.selectedNameFilter())
             chosenext = filtertoext[filterused][0]
@@ -311,7 +309,7 @@ class ExportDialog(VeuszDialog):
             qcolor,
             self,
             "Choose color",
-            qt.QColorDialog.ShowAlphaChannel )
+            qt.QColorDialog.ColorDialogOption.ShowAlphaChannel )
         if color.isValid():
             self.updateExportBackground(utils.extendedColorFromQColor(color))
 
@@ -394,7 +392,7 @@ class ExportDialog(VeuszDialog):
             try:
                 text = cntrl.currentText()
                 valid = cntrl.validator().validate(text, 0)[0]
-                if valid == qt.QValidator.Acceptable:
+                if valid == qt.QValidator.State.Acceptable:
                     setdb[setn] = int(text)
             except ValueError:
                 pass
@@ -417,9 +415,9 @@ class ExportDialog(VeuszDialog):
                 self,
                 _("Overwrite file?"),
                 _("The file %s already exists") % os.path.basename(filename),
-                qt.QMessageBox.Save | qt.QMessageBox.Cancel,
-                qt.QMessageBox.Cancel)
-            return retn == qt.QMessageBox.Save
+                qt.QMessageBox.StandardButton.Save | qt.QMessageBox.StandardButton.Cancel,
+                qt.QMessageBox.StandardButton.Cancel)
+            return retn == qt.QMessageBox.StandardButton.Save
 
         # count exported pages (in list so can be modified in function)
         pagecount = [0]
@@ -430,8 +428,6 @@ class ExportDialog(VeuszDialog):
                     if not _overwriteQuestion(fname):
                         return
 
-            # show busy cursor
-            #qt.QApplication.setOverrideCursor(qt.QCursor(qt.Qt.WaitCursor))
             # delete file if already exists
             try:
                 os.unlink(fname)
@@ -473,8 +469,8 @@ class ExportDialog(VeuszDialog):
         # format feedback
         self.showMessage(_('Processing...'))
 
-        self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(False)
-        self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(False)
+        self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Close).setEnabled(False)
+        self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Save).setEnabled(False)
 
         def checkDone():
             """Check whether exporting has finished."""
@@ -485,10 +481,9 @@ class ExportDialog(VeuszDialog):
             except (RuntimeError, EnvironmentError) as e:
                 # errors from the export
                 if isinstance(e, EnvironmentError):
-                    msg = cstrerror(e)
+                    msg = e.strerror
                 else:
-                    msg = cstr(e)
-                #qt.QApplication.restoreOverrideCursor()
+                    msg = str(e)
                 qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Error exporting to file '%s'\n\n%s") %
@@ -497,8 +492,8 @@ class ExportDialog(VeuszDialog):
                 if pagecount[0] > 0:
                     self.showMessage(_('Exported %i page(s)') % pagecount[0])
 
-            self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(True)
-            self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(True)
+            self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Close).setEnabled(True)
+            self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Save).setEnabled(True)
             self.checktimer.stop()
 
         self.checktimer = qt.QTimer(self)
