@@ -16,7 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 from .. import qtall as qt
 from .. import setting
 from .. import utils
@@ -29,17 +28,17 @@ def _(text, disambiguation=None, context="PrefsDialog"):
 
 # names for display of colors and a longer description
 color_names = {
-    'page': (_('Page'),
-             _('Page background color')),
-    'error': (_('Error'),
-              _('Color for errors')),
-    'command': (_('Console command'),
-                _('Commands in the console window color')),
-    'cntrlline': (_('Control line'),
-                  _('Color of lines controlling widgets')),
-    'cntrlcorner': (_('Control corner'),
-                    _('Color of corners controlling widgets')),
-    }
+    'page': (
+        _('Page'), _('Page background color')),
+    'error': (
+        _('Error'), _('Color for errors')),
+    'command': (
+        _('Console command'), _('Commands in the console window color')),
+    'cntrlline': (
+        _('Control line'), _('Color of lines controlling widgets')),
+    'cntrlcorner': (
+        _('Control corner'), _('Color of corners controlling widgets')),
+}
 
 class PreferencesDialog(VeuszDialog):
     """Preferences dialog."""
@@ -66,14 +65,11 @@ class PreferencesDialog(VeuszDialog):
         self.translationBrowseButton.clicked.connect(
             self.translationBrowseClicked)
 
-        # disable thread option if not supported
-        if not qt.QFontDatabase.supportsThreadedFontRendering():
-            self.threadSpinBox.setEnabled(False)
-            self.threadSpinBox.setToolTip(_("Disabled because of lack of "
-                                            "threaded drawing support"))
-
         # use cwd for file dialogs
-        (self.dirDocCWDRadio if setdb['dirname_usecwd'] else self.dirDocPrevRadio).click()
+        (
+            self.dirDocCWDRadio if setdb['dirname_usecwd']
+            else self.dirDocPrevRadio
+        ).click()
 
         # add import paths
         self.docFileAddImportPaths.setChecked( setdb['docfile_addimportpaths'] )
@@ -215,7 +211,7 @@ class PreferencesDialog(VeuszDialog):
         # use cwd
         setdb['dirname_usecwd'] = self.dirDocCWDRadio.isChecked()
         setdb['docfile_addimportpaths'] = self.docFileAddImportPaths.isChecked()
-        
+
         # add import paths
         setdb['docfile_addimportpaths'] = self.docFileAddImportPaths.isChecked()
 
@@ -223,7 +219,7 @@ class PreferencesDialog(VeuszDialog):
                 (self.dirExportDocRadio, 'doc'),
                 (self.dirExportCWDRadio, 'cwd'),
                 (self.dirExportPrevRadio, 'prev'),
-                ):
+        ):
             if radio.isChecked():
                 setdb['dirname_export_location'] = val
 
@@ -308,8 +304,8 @@ class PreferencesDialog(VeuszDialog):
             [_('Python scripts (*.py)')], _('Choose plugin'))
         if filename:
             self.pluginmodel.insertRows(0, 1)
-            self.pluginmodel.setData( self.pluginmodel.index(0),
-                                      filename )
+            self.pluginmodel.setData(
+                self.pluginmodel.index(0), filename)
 
     def pluginRemoveClicked(self):
         """Remove selected plugin."""
