@@ -23,12 +23,12 @@ Requires: PyQt-x11-gpl-4.6-snapshot-20090906.tar.gz
           pyemf
 """
 
-from __future__ import division, absolute_import
 import struct
 
-import pyemf
+import pyemf3
+import pyemf3.emr
+
 from .. import qtall as qt
-from ..compat import cbytes
 
 inch_mm = 25.4
 scale = 100
@@ -37,66 +37,27 @@ def isStockObject(obj):
     """Is this a stock windows object."""
     return (obj & 0x80000000) != 0
 
-class _EXTCREATEPEN(pyemf._EMR._EXTCREATEPEN):
-    """Extended pen creation record with custom line style."""
-
-    typedef = [
-        ('i','handle',0),
-        ('i','offBmi',0),
-        ('i','cbBmi',0),
-        ('i','offBits',0),
-        ('i','cbBits',0),
-        ('i','style'),
-        ('i','penwidth'),
-        ('i','brushstyle'),
-        ('i','color'),
-        ('i','brushhatch',0),
-        ('i','numstyleentries')
-    ]
-
-    def __init__(self, style=pyemf.PS_SOLID, width=1, color=0,
-                 styleentries=[]):
-        """Create pen.
-        styleentries is a list of dash and space lengths."""
-
-        pyemf._EMR._EXTCREATEPEN.__init__(self)
-        self.style = style
-        self.penwidth = width
-        self.color = pyemf._normalizeColor(color)
-        self.brushstyle = 0x0  # solid
-
-        if style & pyemf.PS_STYLE_MASK != pyemf.PS_USERSTYLE:
-            styleentries = []
-
-        self.numstyleentries = len(styleentries)
-        if styleentries:
-            self.unhandleddata = struct.pack(
-                "i"*self.numstyleentries, *styleentries)
-
-    def hasHandle(self):
-        return True
-
 class EMFPaintEngine(qt.QPaintEngine):
     """Custom EMF paint engine."""
 
     def __init__(self, width_in, height_in, dpi=75):
         qt.QPaintEngine.__init__(
             self,
-            qt.QPaintEngine.Antialiasing |
-            qt.QPaintEngine.PainterPaths |
-            qt.QPaintEngine.PrimitiveTransform |
-            qt.QPaintEngine.PaintOutsidePaintEvent |
-            qt.QPaintEngine.PatternBrush
+            qt.QPaintEngine.PaintEngineFeature.Antialiasing |
+            qt.QPaintEngine.PaintEngineFeature.PainterPaths |
+            qt.QPaintEngine.PaintEngineFeature.PrimitiveTransform |
+            qt.QPaintEngine.PaintEngineFeature.PaintOutsidePaintEvent |
+            qt.QPaintEngine.PaintEngineFeature.PatternBrush
         )
         self.width = width_in
         self.height = height_in
         self.dpi = dpi
 
     def begin(self, paintdevice):
-        self.emf = pyemf.EMF(self.width, self.height, int(self.dpi*scale))
-        self.pen = self.emf.GetStockObject(pyemf.BLACK_PEN)
+        self.emf = pyemf3.EMF(self.width, self.height, int(self.dpi*scale))
+        self.pen = self.emf.GetStockObject(pyemf3.BLACK_PEN)
         self.pencolor = (0, 0, 0)
-        self.brush = self.emf.GetStockObject(pyemf.NULL_BRUSH)
+        self.brush = self.emf.GetStockObject(pyemf3.NULL_BRUSH)
 
         self.paintdevice = paintdevice
         return True
@@ -114,13 +75,13 @@ class EMFPaintEngine(qt.QPaintEngine):
         # print "Polygon"
         pts = [(int(p.x()*scale), int(p.y()*scale)) for p in points]
 
-        if mode == qt.QPaintEngine.PolylineMode:
+        if mode == qt.QPaintEngine.PolygonDrawMode.PolylineMode:
             self.emf.Polyline(pts)
         else:
             self.emf.SetPolyFillMode({
-                qt.QPaintEngine.WindingMode: pyemf.WINDING,
-                qt.QPaintEngine.OddEvenMode: pyemf.ALTERNATE,
-                qt.QPaintEngine.ConvexMode: pyemf.WINDING
+                qt.QPaintEngine.PolygonDrawMode.WindingMode: pyemf3.WINDING,
+                qt.QPaintEngine.PolygonDrawMode.OddEvenMode: pyemf3.ALTERNATE,
+                qt.QPaintEngine.PolygonDrawMode.ConvexMode: pyemf3.WINDING
             })
             self.emf.Polygon(pts)
 
@@ -142,9 +103,10 @@ class EMFPaintEngine(qt.QPaintEngine):
 
         for pt in points:
             x, y = (pt.x()-0.5)*scale, (pt.y()-0.5)*scale
-            self.emf.Pie( int(x), int(y),
-                          int((pt.x()+0.5)*scale), int((pt.y()+0.5)*scale),
-                          int(x), int(y), int(x), int(y) )
+            self.emf.Pie(
+                int(x), int(y),
+                int((pt.x()+0.5)*scale), int((pt.y()+0.5)*scale),
+                int(x), int(y), int(x), int(y) )
 
     def drawPixmap(self, r, pixmap, sr):
         """Draw pixmap to display."""
@@ -152,41 +114,17 @@ class EMFPaintEngine(qt.QPaintEngine):
         # convert pixmap to BMP format
         bytearr = qt.QByteArray()
         buf = qt.QBuffer(bytearr)
-        buf.open(qt.QIODevice.WriteOnly)
+        buf.open(qt.QIODevice.OpenModeFlag.WriteOnly)
         pixmap.save(buf, "BMP")
 
-        # chop off bmp header to get DIB
-        bmp = cbytes(buf.data())
-        dib = bmp[0xe:]
-        hdrsize, = struct.unpack('<i', bmp[0xe:0x12])
-        dataindex, = struct.unpack('<i', bmp[0xa:0xe])
-        datasize, = struct.unpack('<i', bmp[0x22:0x26])
-
-        epix = pyemf._EMR._STRETCHDIBITS()
-        epix.rclBounds_left = int(r.left()*scale)
-        epix.rclBounds_top = int(r.top()*scale)
-        epix.rclBounds_right = int(r.right()*scale)
-        epix.rclBounds_bottom = int(r.bottom()*scale)
-        epix.xDest = int(r.left()*scale)
-        epix.yDest = int(r.top()*scale)
-        epix.cxDest = int(r.width()*scale)
-        epix.cyDest = int(r.height()*scale)
-        epix.xSrc = int(sr.left())
-        epix.ySrc = int(sr.top())
-        epix.cxSrc = int(sr.width())
-        epix.cySrc = int(sr.height())
-
-        epix.dwRop = 0xcc0020 # SRCCOPY
-        offset = epix.format.minstructsize + 8
-        epix.offBmiSrc = offset
-        epix.cbBmiSrc = hdrsize
-        epix.offBitsSrc = offset + dataindex - 0xe
-        epix.cbBitsSrc = datasize
-        epix.iUsageSrc = 0x0 # DIB_RGB_COLORS
-
-        epix.unhandleddata = dib
-
-        self.emf._append(epix)
+        bmp = bytes(buf.data())
+        self.emf.BitmapOut(
+            int(r.left()*scale), int(r.top()*scale),
+            int(r.width()*scale), int(r.bottom()*scale),
+            int(sr.left()), int(sr.top()),
+            int(sr.width()), int(sr.height()),
+            bmp,
+        )
 
     def _createPath(self, path):
         """Convert qt path to emf path"""
@@ -196,13 +134,13 @@ class EMFPaintEngine(qt.QPaintEngine):
         #print "Start path"
         while i < count:
             e = path.elementAt(i)
-            if e.type == qt.QPainterPath.MoveToElement:
+            if e.type == qt.QPainterPath.ElementType.MoveToElement:
                 self.emf.MoveTo( int(e.x*scale), int(e.y*scale) )
                 #print "M", e.x*scale, e.y*scale
-            elif e.type == qt.QPainterPath.LineToElement:
+            elif e.type == qt.QPainterPath.ElementType.LineToElement:
                 self.emf.LineTo( int(e.x*scale), int(e.y*scale) )
                 #print "L", e.x*scale, e.y*scale
-            elif e.type == qt.QPainterPath.CurveToElement:
+            elif e.type == qt.QPainterPath.ElementType.CurveToElement:
                 e1 = path.elementAt(i+1)
                 e2 = path.elementAt(i+2)
                 params = (
@@ -258,47 +196,46 @@ class EMFPaintEngine(qt.QPaintEngine):
 
         # line style
         style = {
-            qt.Qt.NoPen: pyemf.PS_NULL,
-            qt.Qt.SolidLine: pyemf.PS_SOLID,
-            qt.Qt.DashLine: pyemf.PS_DASH,
-            qt.Qt.DotLine: pyemf.PS_DOT,
-            qt.Qt.DashDotLine: pyemf.PS_DASHDOT,
-            qt.Qt.DashDotDotLine: pyemf.PS_DASHDOTDOT,
-            qt.Qt.CustomDashLine: pyemf.PS_USERSTYLE,
+            qt.Qt.PenStyle.NoPen: pyemf3.PS_NULL,
+            qt.Qt.PenStyle.SolidLine: pyemf3.PS_SOLID,
+            qt.Qt.PenStyle.DashLine: pyemf3.PS_DASH,
+            qt.Qt.PenStyle.DotLine: pyemf3.PS_DOT,
+            qt.Qt.PenStyle.DashDotLine: pyemf3.PS_DASHDOT,
+            qt.Qt.PenStyle.DashDotDotLine: pyemf3.PS_DASHDOTDOT,
+            qt.Qt.PenStyle.CustomDashLine: pyemf3.PS_USERSTYLE,
         }[pen.style()]
 
-        if style != pyemf.PS_NULL:
+        if style != pyemf3.PS_NULL:
             # set cap style
             style |= {
-                qt.Qt.FlatCap: pyemf.PS_ENDCAP_FLAT,
-                qt.Qt.SquareCap: pyemf.PS_ENDCAP_SQUARE,
-                qt.Qt.RoundCap: pyemf.PS_ENDCAP_ROUND,
+                qt.Qt.PenCapStyle.FlatCap: pyemf3.PS_ENDCAP_FLAT,
+                qt.Qt.PenCapStyle.SquareCap: pyemf3.PS_ENDCAP_SQUARE,
+                qt.Qt.PenCapStyle.RoundCap: pyemf3.PS_ENDCAP_ROUND,
             }[pen.capStyle()]
 
             # set join style
             style |= {
-                qt.Qt.MiterJoin: pyemf.PS_JOIN_MITER,
-                qt.Qt.BevelJoin: pyemf.PS_JOIN_BEVEL,
-                qt.Qt.RoundJoin: pyemf.PS_JOIN_ROUND,
-                qt.Qt.SvgMiterJoin: pyemf.PS_JOIN_MITER,
+                qt.Qt.PenJoinStyle.MiterJoin: pyemf3.PS_JOIN_MITER,
+                qt.Qt.PenJoinStyle.BevelJoin: pyemf3.PS_JOIN_BEVEL,
+                qt.Qt.PenJoinStyle.RoundJoin: pyemf3.PS_JOIN_ROUND,
+                qt.Qt.PenJoinStyle.SvgMiterJoin: pyemf3.PS_JOIN_MITER,
             }[pen.joinStyle()]
 
             # use proper widths of lines
-            style |= pyemf.PS_GEOMETRIC
+            style |= pyemf3.PS_GEOMETRIC
 
         width = int(pen.widthF()*scale)
         qc = pen.color()
         color = (qc.red(), qc.green(), qc.blue())
         self.pencolor = color
 
-        if pen.style() == qt.Qt.CustomDashLine:
-            # make an extended pen if we need a custom dash pattern
+        if pen.style() == qt.Qt.PenStyle.CustomDashLine:
+            # custom dash pattern
             dash = [int(pen.widthF()*scale*f) for f in pen.dashPattern()]
-            newpen = self.emf._appendHandle( _EXTCREATEPEN(
-                style, width=width, color=color, styleentries=dash))
         else:
-            # use a standard create pen
-            newpen = self.emf.CreatePen(style, width, color)
+            dash = None
+
+        newpen = self.emf.CreatePen(style, width, color, styleentries=dash)
         self.emf.SelectObject(newpen)
 
         # delete old pen if it is not a stock object
@@ -313,19 +250,19 @@ class EMFPaintEngine(qt.QPaintEngine):
         qc = brush.color()
         color = (qc.red(), qc.green(), qc.blue())
         # print "brush", color
-        if style == qt.Qt.SolidPattern:
+        if style == qt.Qt.BrushStyle.SolidPattern:
             newbrush = self.emf.CreateSolidBrush(color)
-        elif style == qt.Qt.NoBrush:
-            newbrush = self.emf.GetStockObject(pyemf.NULL_BRUSH)
+        elif style == qt.Qt.BrushStyle.NoBrush:
+            newbrush = self.emf.GetStockObject(pyemf3.NULL_BRUSH)
         else:
             try:
                 hatch = {
-                    qt.Qt.HorPattern: pyemf.HS_HORIZONTAL,
-                    qt.Qt.VerPattern: pyemf.HS_VERTICAL,
-                    qt.Qt.CrossPattern: pyemf.HS_CROSS,
-                    qt.Qt.BDiagPattern: pyemf.HS_BDIAGONAL,
-                    qt.Qt.FDiagPattern: pyemf.HS_FDIAGONAL,
-                    qt.Qt.DiagCrossPattern: pyemf.HS_DIAGCROSS
+                    qt.Qt.BrushStyle.HorPattern: pyemf3.HS_HORIZONTAL,
+                    qt.Qt.BrushStyle.VerPattern: pyemf3.HS_VERTICAL,
+                    qt.Qt.BrushStyle.CrossPattern: pyemf3.HS_CROSS,
+                    qt.Qt.BrushStyle.BDiagPattern: pyemf3.HS_BDIAGONAL,
+                    qt.Qt.BrushStyle.FDiagPattern: pyemf3.HS_FDIAGONAL,
+                    qt.Qt.BrushStyle.DiagCrossPattern: pyemf3.HS_DIAGCROSS
                 }[brush.style()]
             except KeyError:
                 newbrush = self.emf.CreateSolidBrush(color)
@@ -340,11 +277,11 @@ class EMFPaintEngine(qt.QPaintEngine):
     def _updateClipPath(self, path, operation):
         """Update clipping path."""
         # print "clip"
-        if operation != qt.Qt.NoClip:
+        if operation != qt.Qt.ClipOperation.NoClip:
             self._createPath(path)
             clipmode = {
-                 qt.Qt.ReplaceClip: pyemf.RGN_COPY,
-                 qt.Qt.IntersectClip: pyemf.RGN_AND,
+                 qt.Qt.ClipOperation.ReplaceClip: pyemf3.RGN_COPY,
+                 qt.Qt.ClipOperation.IntersectClip: pyemf3.RGN_AND,
             }[operation]
         else:
             # is this the only wave to get rid of clipping?
@@ -357,34 +294,35 @@ class EMFPaintEngine(qt.QPaintEngine):
             self.emf.LineTo(0, h)
             self.emf.CloseFigure()
             self.emf.EndPath()
-            clipmode = pyemf.RGN_COPY
+            clipmode = pyemf3.RGN_COPY
 
         self.emf.SelectClipPath(mode=clipmode)
 
     def _updateTransform(self, m):
         """Update transformation."""
-        self.emf.SetWorldTransform(m.m11(), m.m12(),
-                                   m.m21(), m.m22(),
-                                   m.dx()*scale, m.dy()*scale)
+        self.emf.SetWorldTransform(
+            m.m11(), m.m12(),
+            m.m21(), m.m22(),
+            m.dx()*scale, m.dy()*scale)
 
     def updateState(self, state):
         """Examine what has changed in state and call apropriate function."""
         ss = state.state()
-        if ss & qt.QPaintEngine.DirtyPen:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyPen:
             self._updatePen(state.pen())
-        if ss & qt.QPaintEngine.DirtyBrush:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyBrush:
             self._updateBrush(state.brush())
-        if ss & qt.QPaintEngine.DirtyTransform:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyTransform:
             self._updateTransform(state.transform())
-        if ss & qt.QPaintEngine.DirtyClipPath:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyClipPath:
             self._updateClipPath(state.clipPath(), state.clipOperation())
-        if ss & qt.QPaintEngine.DirtyClipRegion:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyClipRegion:
             path = qt.QPainterPath()
             path.addRegion(state.clipRegion())
             self._updateClipPath(path, state.clipOperation())
 
     def type(self):
-        return qt.QPaintEngine.PostScript
+        return qt.QPaintEngine.Type(qt.QPaintEngine.Type.User.value + 12)
 
 class EMFPaintDevice(qt.QPaintDevice):
     """Paint device for EMF paint engine."""
@@ -398,27 +336,27 @@ class EMFPaintDevice(qt.QPaintDevice):
 
     def metric(self, m):
         """Return the metrics of the painter."""
-        if m == qt.QPaintDevice.PdmWidth:
+        if m == qt.QPaintDevice.PaintDeviceMetric.PdmWidth:
             return int(self.engine.width * self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmHeight:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmHeight:
             return int(self.engine.height * self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmWidthMM:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmWidthMM:
             return int(self.engine.width * inch_mm)
-        elif m == qt.QPaintDevice.PdmHeightMM:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmHeightMM:
             return int(self.engine.height * inch_mm)
-        elif m == qt.QPaintDevice.PdmNumColors:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmNumColors:
             return 2147483647
-        elif m == qt.QPaintDevice.PdmDepth:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDepth:
             return 24
-        elif m == qt.QPaintDevice.PdmDpiX:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDpiX:
             return int(self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmDpiY:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDpiY:
             return int(self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmPhysicalDpiX:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmPhysicalDpiX:
             return int(self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmPhysicalDpiY:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmPhysicalDpiY:
             return int(self.engine.dpi)
-        elif m == qt.QPaintDevice.PdmDevicePixelRatio:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDevicePixelRatio:
             return 1
 
         # Qt >= 5.6
