@@ -18,7 +18,6 @@
 
 """A database for default values of settings."""
 
-from __future__ import division, print_function
 import sys
 import datetime
 
@@ -118,7 +117,7 @@ defaultValues = {
     'secure_unsaved': True,
 }
 
-class _SettingDB(object):
+class _SettingDB:
     """A class which provides access to a persistant settings database.
 
     Items are accesses as a dict, with items as key=value
@@ -133,7 +132,7 @@ class _SettingDB(object):
         'command': 'blue',
         'cntrlline': 'blue',
         'cntrlcorner': 'black',
-        }
+    }
 
     def __init__(self):
         """Initialise the object, reading the settings."""
@@ -154,9 +153,10 @@ class _SettingDB(object):
         if val[0]:
             default = self.color_defaults[name]
             if default == 'LightBase':
-                base = qt.qApp.palette().color(qt.QPalette.Base)
+                base = qt.QGuiApplication.palette().color(
+                    qt.QPalette.ColorRole.Base)
                 if base.value() < 127:
-                    base = qt.QColor(qt.Qt.white)
+                    base = qt.QColor(qt.Qt.GlobalColor.white)
                 return base
 
             return qt.QColor(default)
@@ -183,8 +183,9 @@ class _SettingDB(object):
             try:
                 self.database[realkey] = eval(val)
             except:
-                print('Error interpreting item "%s" in '
-                      'settings file' % realkey, file=sys.stderr)
+                print(
+                    'Error interpreting item "%s" in '
+                    'settings file' % realkey, file=sys.stderr)
 
         # set any defaults which haven't been set
         for key in defaultValues:
@@ -254,7 +255,7 @@ def updateUILocale():
         uilocale = qt.QLocale.c()
     else:
         uilocale = qt.QLocale.system()
-    uilocale.setNumberOptions(qt.QLocale.OmitGroupSeparator)
+    uilocale.setNumberOptions(qt.QLocale.NumberOption.OmitGroupSeparator)
 
     qt.QLocale.setDefault(uilocale)
 
