@@ -27,23 +27,21 @@ Quit: exit the listening program
 Zoom x: Change the zoom factor of the plot to x
 """
 
-from __future__ import division
 import sys
 
-from . import qtall as qt4
-from .compat import cstr
+from . import qtall as qt
 
 from .windows.simplewindow import SimpleWindow
 from . import document
 
-class ReadingThread(qt4.QThread):
+class ReadingThread(qt.QThread):
     """Stdin reading thread. Emits newline signals with new data.
 
     We could use a QSocketNotifier on Unix, but this doesn't work on
     Windows as its stdin is a weird object
     """
 
-    newline = qt4.pyqtSignal(cstr)
+    newline = qt.pyqtSignal(str)
 
     def run(self):
         """Emit lines read from stdin."""
@@ -53,14 +51,14 @@ class ReadingThread(qt4.QThread):
                 break
             self.newline.emit(line)
 
-class InputListener(qt4.QObject):
+class InputListener(qt.QObject):
     """Class reads text from stdin, in order to send commands to a document."""
 
     def __init__(self, window):
         """Initialse the listening object to send commands to the
         document given by window."""
-        
-        qt4.QObject.__init__(self)
+
+        qt.QObject.__init__(self)
 
         self.window = window
         self.document = window.document
@@ -115,7 +113,7 @@ class InputListener(qt4.QObject):
     def enableToolbar(self, enable=True):
         """Enable plot toolbar."""
         self.window.enableToolbar(enable)
-        
+
     def enablePickle(self, on=True):
         """Enable/disable pickling of commands to/data from veusz"""
         self.pickle = on
@@ -127,7 +125,7 @@ class InputListener(qt4.QObject):
             retn = self.ci.runPickle( eval(line.strip()) )
             sys.stdout.write('%s\n' % repr(retn))
             sys.stdout.flush()
-            
+
         else:
             self.ci.run(line)
 
@@ -150,9 +148,9 @@ def openWindow(args, quiet=False):
 
 def run():
     '''Actually run the program.'''
-    app = qt4.QApplication(sys.argv)
+    app = qt.QApplication(sys.argv)
     openWindow(sys.argv)
-    app.exec_()
+    app.exec()
 
 # if ran as a program
 if __name__ == '__main__':
