@@ -19,14 +19,11 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 import codeop
 import traceback
 import sys
 
-from ..compat import cstr
-from .. import qtall as qt4
-
+from .. import qtall as qt
 from .. import document
 from .. import utils
 from .. import setting
@@ -35,35 +32,42 @@ from .. import setting
 
 def _(text, disambiguation=None, context='ConsoleWindow'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
-class _Writer(object):
+class _Writer:
     """ Class to behave like an output stream. Pipes input back to
     the specified function."""
 
     def __init__(self, function):
-        """ Set the function output is sent to."""
+        """Set the function output is sent to."""
         self.function = function
 
     def write(self, text):
-        """ Send text to the output function."""
+        """Send text to the output function."""
         self.function(text)
 
     def flush(self):
-        """ Does nothing as yet."""
+        """Does nothing as yet."""
         pass
 
-class _CommandEdit(qt4.QLineEdit):
+class _Reader:
+    """Fake reading input stream object."""
+    def read(self, *args):
+        raise IOError('Interactive input not supported')
+    def readline(self, *args):
+        raise IOError('Interactive input not supported')
+
+class _CommandEdit(qt.QLineEdit):
     """ A special class to allow entering of the command line.
 
     emits sigEnter if the return key is pressed, and returns command
     The edit control has a history (press up and down keys to access)
     """
 
-    sigEnter = qt4.pyqtSignal(cstr)
+    sigEnter = qt.pyqtSignal(str)
 
     def __init__(self, *args):
-        qt4.QLineEdit.__init__(self, *args)
+        qt.QLineEdit.__init__(self, *args)
         self.history = []
         self.history_posn = 0
         self.entered_text = ''
@@ -80,19 +84,19 @@ class _CommandEdit(qt4.QLineEdit):
         self.setText("")
 
         # keep the command for history
-        self.history.append( command )
+        self.history.append(command)
         self.history_posn = len(self.history)
         self.entered_text = ''
 
         # tell the console we have a command
         self.sigEnter.emit(command)
 
-    historykeys = (qt4.Qt.Key_Up, qt4.Qt.Key_Down)
+    historykeys = (qt.Qt.Key.Key_Up, qt.Qt.Key.Key_Down)
 
     def keyPressEvent(self, key):
         """ Overridden to handle history. """
 
-        qt4.QLineEdit.keyPressEvent(self, key)
+        qt.QLineEdit.keyPressEvent(self, key)
         code = key.key()
 
         # check whether one of the "history keys" has been pressed
@@ -106,9 +110,9 @@ class _CommandEdit(qt4.QLineEdit):
             else:
                 text = self.entered_text
 
-            if code == qt4.Qt.Key_Up:
+            if code == qt.Qt.Key.Key_Up:
                 step = -1
-            elif code == qt4.Qt.Key_Down:
+            elif code == qt.Qt.Key.Key_Down:
                 step = 1
 
             newpos = self.history_posn + step
@@ -140,57 +144,60 @@ class _CommandEdit(qt4.QLineEdit):
             text = self.history[ self.history_posn ]
             self.setText(text)
 
-introtext=_(u'''Welcome to <b><font color="purple">Veusz %s</font></b> --- a scientific plotting application.<br>
-Copyright \u00a9 2003-2014 Jeremy Sanders &lt;jeremy@jeremysanders.net&gt; and contributors.<br>
+introtext=_('''Welcome to <b><font color="purple">Veusz %s</font></b> --- a scientific plotting application.<br>
+Copyright \u00a9 2003-2025 Jeremy Sanders &lt;jeremy@jeremysanders.net&gt; and contributors.<br>
 Veusz comes with ABSOLUTELY NO WARRANTY. Veusz is Free Software, and you are<br>
 welcome to redistribute it under certain conditions. Enter "GPL()" for details.<br>
 This window is a Python command line console and acts as a calculator.<br>
 ''') % utils.version()
 
-class ConsoleWindow(qt4.QDockWidget):
+class ConsoleWindow(qt.QDockWidget):
     """ A python-like qt console."""
 
     def __init__(self, thedocument, *args):
-        qt4.QDockWidget.__init__(self, *args)
+        qt.QDockWidget.__init__(self, *args)
         self.setWindowTitle(_("Console - Veusz"))
         self.setObjectName("veuszconsolewindow")
 
         # arrange sub-widgets in a vbox
-        self.vbox = qt4.QWidget()
+        self.vbox = qt.QWidget()
         self.setWidget(self.vbox)
-        vlayout = qt4.QVBoxLayout(self.vbox)
-        vlayout.setMargin( vlayout.margin()//4 )
-        vlayout.setSpacing( vlayout.spacing()//4 )
+        vlayout = qt.QVBoxLayout(self.vbox)
+        s = vlayout.contentsMargins().left()//4
+        vlayout.setContentsMargins(s,s,s,s)
+        vlayout.setSpacing(s)
 
         # start an interpreter instance to the document
         self.interpreter = document.CommandInterpreter(thedocument)
         self.document = thedocument
-        # output from the interpreter goes to self.output_stdxxx
 
+        # streams the output/input goes to/from
         self.con_stdout = _Writer(self.output_stdout)
         self.con_stderr = _Writer(self.output_stderr)
+        self.con_stdin = _Reader()
 
-        self.interpreter.setOutputs(self.con_stdout, self.con_stderr)
+        self.interpreter.setFiles(
+            self.con_stdout, self.con_stderr, self.con_stdin)
         self.stdoutbuffer = ""
         self.stderrbuffer = ""
 
         # (mostly) hidden notification
-        self._hiddennotify = qt4.QLabel()
+        self._hiddennotify = qt.QLabel()
         vlayout.addWidget(self._hiddennotify)
         self._hiddennotify.hide()
 
         # the output from the console goes here
-        self._outputdisplay = qt4.QTextEdit()
+        self._outputdisplay = qt.QTextEdit()
         self._outputdisplay.setReadOnly(True)
         self._outputdisplay.insertHtml( introtext )
         vlayout.addWidget(self._outputdisplay)
 
-        self._hbox = qt4.QWidget()
-        hlayout = qt4.QHBoxLayout(self._hbox)
-        hlayout.setMargin(0)
+        self._hbox = qt.QWidget()
+        hlayout = qt.QHBoxLayout(self._hbox)
+        hlayout.setContentsMargins(0,0,0,0)
         vlayout.addWidget(self._hbox)
-        
-        self._prompt = qt4.QLabel(">>>")
+
+        self._prompt = qt.QLabel(">>>")
         hlayout.addWidget(self._prompt)
 
         # where commands are typed in
@@ -208,9 +215,9 @@ class ConsoleWindow(qt4.QDockWidget):
 
     def _makeTextFormat(self, cursor, color):
         fmt = cursor.charFormat()
-        
+
         if color is not None:
-            brush = qt4.QBrush(color)
+            brush = qt.QBrush(color)
             fmt.setForeground(brush)
         else:
             # use the default foreground color
@@ -228,7 +235,7 @@ class ConsoleWindow(qt4.QDockWidget):
             color = None
 
         cursor = self._outputdisplay.textCursor()
-        cursor.movePosition(qt4.QTextCursor.End)
+        cursor.movePosition(qt.QTextCursor.MoveOperation.End)
         cursor.insertText(text, self._makeTextFormat(cursor, color))
         self._outputdisplay.setTextCursor(cursor)
         self._outputdisplay.ensureCursorVisible()
@@ -238,36 +245,33 @@ class ConsoleWindow(qt4.QDockWidget):
         exceptions."""
 
         # preserve output streams
-        temp_stdout = sys.stdout
-        temp_stderr = sys.stderr
-        sys.stdout = _Writer(self.output_stdout)
-        sys.stderr = _Writer(self.output_stderr)
+        saved = sys.stdout, sys.stderr, sys.stdin
+        sys.stdout, sys.stderr, sys.stdin = (
+            self.con_stdout, self.con_stderr, self.con_stdin)
 
         # catch any exceptions, printing problems to stderr
-        self.document.suspendUpdates()
-        try:
-            func()
-        except:
-            # print out the backtrace to stderr
-            i = sys.exc_info()
-            backtrace = traceback.format_exception( *i )
-            for l in backtrace:
-                sys.stderr.write(l)            
-        self.document.enableUpdates()
+        with self.document.suspend():
+            try:
+                func()
+            except:
+                # print out the backtrace to stderr
+                info = sys.exc_info()
+                backtrace = traceback.format_exception(*info)
+                for line in backtrace:
+                    sys.stderr.write(line)
 
         # return output streams
-        sys.stdout = temp_stdout
-        sys.stderr = temp_stderr
+        sys.stdout, sys.stderr, sys.stdin = saved
 
     def checkVisible(self):
         """If this window is hidden, show it, then hide it again in a few
         seconds."""
         if self.isHidden():
-            self._hiddennotify.setText(_("This window will shortly disappear. "
-                                         "You can bring it back by selecting "
-                                         "View, Windows, Console Window on the "
-                                         "menu."))
-            qt4.QTimer.singleShot(5000, self.hideConsole)
+            self._hiddennotify.setText(_(
+                "This window will shortly disappear. "
+                "You can bring it back by selecting "
+                "View, Windows, Console Window on the menu."))
+            qt.QTimer.singleShot(5000, self.hideConsole)
             self.show()
             self._hiddennotify.show()
 
@@ -298,10 +302,10 @@ class ConsoleWindow(qt4.QDockWidget):
         # check whether command can be compiled
         # c set to None if incomplete
         try:
-            c = codeop.compile_command(newc)
+            comp = codeop.compile_command(newc)
         except Exception:
             # we want errors to be caught by self.interpreter.run below
-            c = 1
+            comp = 1
 
         # which prompt?
         prompt = '>>>'
@@ -312,19 +316,20 @@ class ConsoleWindow(qt4.QDockWidget):
         self.appendOutput('%s %s\n' % (prompt, command), 'command')
 
         # are we ready to run this?
-        if c is None or (len(command) != 0 and
-                         len(self.command_build) != 0 and
-                         (command[0] == ' ' or command[0] == '\t')):
+        if comp is None or (
+                len(command) != 0 and
+                len(self.command_build) != 0 and
+                (command[0] == ' ' or command[0] == '\t')):
             # build up the expression
             self.command_build = newc
             # modify the prompt
-            self._prompt.setText( '...' )
+            self._prompt.setText('...')
         else:
             # actually execute the command
             self.interpreter.run(newc)
             self.command_build = ''
             # modify the prompt
-            self._prompt.setText( '>>>' )
+            self._prompt.setText('>>>')
 
     def slotDocumentLog(self, text):
         """Output information if the document logs something."""
